==> resource-registry-client-4.5.0-20260209.145026-36-sources.jar: org/gcube/informationsystem/resourceregistry/client/ResourceRegistryClientFactory.java <==
package org.gcube.informationsystem.resourceregistry.client;

import org.gcube.informationsystem.resourceregistry.api.Constants;
import org.gcube.informationsystem.resourceregistry.api.rest.ServiceInstance;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class ResourceRegistryClientFactory {
	
	private static final Logger logger = LoggerFactory.getLogger(ResourceRegistryClientFactory.class);
	
	/**
	 * Gets the Resource Registry service URL using the current context.
	 * 
	 * @return The complete URL for the Resource Registry service
	 */
	public static String getResourceRegistryURL() {
		String address = String.format("%s/%s", ServiceInstance.getServiceURL(),Constants.SERVICE_NAME);
		return address;
	}
	
	/**
	 * Gets the Resource Registry service URL for a specific context.
	 * 
	 * @param context The context to use for determining the service URL
	 * @return The complete URL for the Resource Registry service in the specified context
	 */
	public static String getResourceRegistryURL(String context) {
		String address = String.format("%s/%s", ServiceInstance.getServiceURL(context),Constants.SERVICE_NAME);
		return address;
	}
	
	/**
	 * Creates a new ResourceRegistryClient instance using the current context.
	 * 
	 * @return A new ResourceRegistryClient instance configured for the current context
	 */
	public static ResourceRegistryClient create() {
		String address = getResourceRegistryURL();
		logger.trace("The {} will be contacted at {}", Constants.SERVICE_NAME, address);
		return new ResourceRegistryClientImpl(address);
	}
	
	/**
	 * Creates a new ResourceRegistryClient instance for a specific context.
	 * 
	 * @param context The context to use for the ResourceRegistryClient instance
	 * @return A new ResourceRegistryClient instance configured for the specified context
	 */
	public static ResourceRegistryClient create(String context) {
		String address = getResourceRegistryURL(context);
		logger.trace("The {} will be contacted at {}", Constants.SERVICE_NAME, address);
		return new ResourceRegistryClientImpl(address);
	}
	
}

==> resource-registry-client-5.0.0-20251107.134338-23-sources.jar: org/gcube/informationsystem/resourceregistry/client/ResourceRegistryClientFactory.java <==
package org.gcube.informationsystem.resourceregistry.client;

import org.gcube.informationsystem.resourceregistry.api.Constants;
import org.gcube.informationsystem.resourceregistry.api.rest.ServiceInstance;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class ResourceRegistryClientFactory {
	
	private static final Logger logger = LoggerFactory.getLogger(ResourceRegistryClientFactory.class);
	
	/**
	 * Gets the Resource Registry service URL using the current context.
	 * 
	 * @return The complete URL for the Resource Registry service
	 */
	public static String getResourceRegistryURL() {
		String address = "%s/%s".formatted(ServiceInstance.getServiceURL(), Constants.SERVICE_NAME);
		return address;
	}
	
	/**
	 * Gets the Resource Registry service URL for a specific context.
	 * 
	 * @param context The context to use for determining the service URL
	 * @return The complete URL for the Resource Registry service in the specified context
	 */
	public static String getResourceRegistryURL(String context) {
		String address = "%s/%s".formatted(ServiceInstance.getServiceURL(context), Constants.SERVICE_NAME);
		return address;
	}
	
	/**
	 * Creates a new ResourceRegistryClient instance using the current context.
	 * 
	 * @return A new ResourceRegistryClient instance configured for the current context
	 */
	public static ResourceRegistryClient create() {
		String address = getResourceRegistryURL();
		logger.trace("The {} will be contacted at {}", Constants.SERVICE_NAME, address);
		return new ResourceRegistryClientImpl(address);
	}
	
	/**
	 * Creates a new ResourceRegistryClient instance for a specific context.
	 * 
	 * @param context The context to use for the ResourceRegistryClient instance
	 * @return A new ResourceRegistryClient instance configured for the specified context
	 */
	public static ResourceRegistryClient create(String context) {
		String address = getResourceRegistryURL(context);
		logger.trace("The {} will be contacted at {}", Constants.SERVICE_NAME, address);
		return new ResourceRegistryClientImpl(address);
	}
	
}
